@@ -12,6 +12,5 @@ class pell_grant_simplified_formula_applies(Variable):
         head_income = tax_unit("pell_grant_primary_income", period)
         p = parameters(period).gov.ed.pell_grant.efc.simplified
         income_eligible = head_income < p.income_limit
-        total_benefits = add(tax_unit, period, p.benefits)
-        has_benefits = np.any(total_benefits > 0)
+        has_benefits = add(tax_unit, period, p.benefits) > 0
         return income_eligible & has_benefits & p.applies
