@@ -9,11 +9,11 @@ class dwks19(Variable):
     unit = USD
 
     def formula(tax_unit, period, parameters):
+        p = parameters(period).gov.irs.capital_gains
         dwks14 = tax_unit("dwks14", period)
-        capital_gains = parameters(period).gov.irs.capital_gains.brackets
         filing_status = tax_unit("filing_status", period)
         dwks01 = tax_unit("taxable_income", period)
-        dwks16 = min_(capital_gains.thresholds["1"][filing_status], dwks01)
+        dwks16 = min_(p.thresholds["1"][filing_status], dwks01)
         dwks17 = min_(dwks14, dwks16)
         dwks10 = tax_unit("dwks10", period)
         dwks18 = max_(0, dwks01 - dwks10)
