@@ -11,5 +11,7 @@ class la_standard_deduction(Variable):
 
     def formula(tax_unit, period, parameters):
         p = parameters(period).gov.states.la.tax.income.deductions.standard
-        filing_status = tax_unit("filing_status", period)
-        return p.amount[filing_status]
+        if p.applies:
+            filing_status = tax_unit("filing_status", period)
+            return p.amount[filing_status]
+        return 0
