@@ -20,11 +20,13 @@ class wi_married_couple_credit(Variable):
         fstatus = tax_unit("filing_status", period)
         eligible = fstatus == fstatus.possible_values.JOINT
         p = parameters(period).gov.states.wi.tax.income.credits
-        income = add(tax_unit.members, period, p.married_couple.income_sources)
-        is_head = tax_unit.members("is_tax_unit_head", period)
-        is_spouse = tax_unit.members("is_tax_unit_spouse", period)
-        head_income = tax_unit.sum(is_head * income)
-        spouse_income = tax_unit.sum(is_spouse * income)
+        person = tax_unit.members
+        income = add(person, period, p.married_couple.income_sources)
+        floored_income = max_(0, income)
+        is_head = person("is_tax_unit_head", period)
+        is_spouse = person("is_tax_unit_spouse", period)
+        head_income = tax_unit.sum(is_head * floored_income)
+        spouse_income = tax_unit.sum(is_spouse * floored_income)
         lower_income = min_(head_income, spouse_income)
         return min_(
             eligible * lower_income * p.married_couple.rate,
