@@ -10,7 +10,7 @@ class snap_self_employment_income_after_expense_deduction(Variable):
 
     def formula(spm_unit, period, parameters):
         self_employment_income = add(
-            spm_unit, period, ["self_employment_income"]
+            spm_unit, period, ["self_employment_income_before_lsr"]
         )
         expense_deduction = spm_unit(
             "snap_self_employment_expense_deduction", period
